@@ -9,7 +9,8 @@ from django.utils.translation import ugettext_lazy as _
 
 from cms.models import CMSPlugin
 from cms.models.fields import PlaceholderField
-from django_countries import CountryField
+from django_countries.fields import CountryField
+from filer.fields.image import FilerImageField
 from hvad.models import TranslatedFields, TranslatableModel, TranslationManager
 
 from .settings import DISPLAY_TYPE_CHOICES
@@ -185,6 +186,11 @@ class Event(TranslatableModel):
         null=True, blank=True,
     )
 
+    image = FilerImageField(
+        verbose_name=_('Image'),
+        null=True, blank=True,
+    )
+
     translations = TranslatedFields(
         title=models.CharField(
             max_length=512,
@@ -281,9 +287,6 @@ class Event(TranslatableModel):
         amount = self.end_date - self.start_date
         return amount.days + 1
 
-    def get_title(self):
-        return self.title
-
 
 class EventPluginModel(CMSPlugin):
     """
