@@ -2,8 +2,11 @@
 from django.template import RequestContext
 from django.test import TestCase, RequestFactory
 
-from ..templatetags.multilingual_events_tags import get_events
-from .factories import EventFactory
+from ..templatetags.multilingual_events_tags import (
+    get_events,
+    get_event_categories,
+)
+from .factories import EventFactory, EventCategoryFactory
 
 
 class GetEventsTestCase(TestCase):
@@ -25,3 +28,13 @@ class GetEventsTestCase(TestCase):
         self.assertEqual(result.count(), 0, msg=(
             'When no LANGUAGE_CODE can be found, it should return an empty'
             ' QuerySet'))
+
+
+class GetEventCategoriesTestCase(TestCase):
+    """Tests for the ``get_event_categories`` templatetag."""
+    longMessage = True
+
+    def test_tag(self):
+        EventCategoryFactory()
+        self.assertEqual(get_event_categories().count(), 1, msg=(
+            'Should return one category.'))
